@@ -8,8 +8,10 @@
 
 .QC$package.description <- 'Comprehensive, efficient and easy to use quality control of genome-wide association study results'
 
-.QC$script.version <- '1.1.2'
+.QC$script.version <- '1.2'
 
 .QC$url <- "GWASinspector.com"
 
-.QC$help <- 'Check out our website for help and support'
+.QC$help <- 'Check out our website for more help and support'
+
+.QC$vignetteLink <- 'Manual is available from vignette("GWASinspector")'
