@@ -207,12 +207,12 @@ create.xlsx.report <- function(config,study.list){
     sapply(study.list, function(x) return(x$PVcor)),
     sapply(study.list, function(x) return(x$Visschers.stat.HQ)),
     rep(' ', length(study.list)),
-    sapply(study.list, function(x) return(x$tables$variable.summary['Min.', .QC$config$parameters$effect_type_string])),
-    sapply(study.list, function(x) return(x$tables$variable.summary['1st Qu.', .QC$config$parameters$effect_type_string])),
-    sapply(study.list, function(x) return(x$tables$variable.summary['Median', .QC$config$parameters$effect_type_string])),
-    sapply(study.list, function(x) return(x$tables$variable.summary['Mean', .QC$config$parameters$effect_type_string])),
-    sapply(study.list, function(x) return(x$tables$variable.summary['3rd Qu.', .QC$config$parameters$effect_type_string])),
-    sapply(study.list, function(x) return(x$tables$variable.summary['Max.', .QC$config$parameters$effect_type_string])),
+    sapply(study.list, function(x) return(x$tables$variable.summary['Min.', .QC$config$input_parameters$effect_type_string])),
+    sapply(study.list, function(x) return(x$tables$variable.summary['1st Qu.', .QC$config$input_parameters$effect_type_string])),
+    sapply(study.list, function(x) return(x$tables$variable.summary['Median', .QC$config$input_parameters$effect_type_string])),
+    sapply(study.list, function(x) return(x$tables$variable.summary['Mean', .QC$config$input_parameters$effect_type_string])),
+    sapply(study.list, function(x) return(x$tables$variable.summary['3rd Qu.', .QC$config$input_parameters$effect_type_string])),
+    sapply(study.list, function(x) return(x$tables$variable.summary['Max.', .QC$config$input_parameters$effect_type_string])),
     sapply(study.list, function(x) return(x$tables$variable.summary['Median','STDERR'])),
     sapply(study.list, function(x) return(x$fixed.hwep)),
     sapply(study.list, function(x) return(x$fixed.impq)),
@@ -243,7 +243,7 @@ create.xlsx.report <- function(config,study.list){
                               'Lambda - Imputed',
                               'P-value Correlation',
                               "Visscher's Statistic (HQ variants)",
-                              .QC$config$parameters$effect_type_string,
+                              .QC$config$input_parameters$effect_type_string,
                               "      Min.",
                               "      1st Qu.",
                               "      Median",
